@@ -8,27 +8,32 @@ pub mod json;
 pub mod bincode;
 
 use crate::manifest::SyntaxOption;
+use displaydoc::Display;
 use std::io;
 use std::ops::Deref;
 
 /// An Error type specifically for the [`Serializer`](serde::Serializer) that doesn't carry filenames
+#[derive(Display, Debug)]
 pub enum Error {
+    #[displaydoc("{0}")]
     Io(io::Error),
+    #[displaydoc("{0}")]
     Serializer(erased_serde::Error),
 }
 
+impl std::error::Error for Error {}
+
 impl From<io::Error> for Error {
-    fn from(err: io::Error) -> Self {
-        Self::Io(err)
+    fn from(e: io::Error) -> Self {
+        Error::Io(e)
     }
 }
 
 impl From<erased_serde::Error> for Error {
-    fn from(err: erased_serde::Error) -> Self {
-        Self::Serializer(err)
+    fn from(e: erased_serde::Error) -> Self {
+        Error::Serializer(e)
     }
 }
-
 /// A simple serializer trait that works on whole objects.
 pub trait AbstractSerializer: Deref<Target = SyntaxOption> {
     /// Serializes an object to a sink.
